---
title: "{{ env.TITLE }}"
labels: ["maintenance"]
---

The rust toolchain is outdated. Current pinned release is {{ env.CURRENT_RUST_VERSION }} where the latest stable release is {{ env.LATEST_RUST_VERSION }}